OC.L10N.register(
    "user_ldap",
    {
    "Users" : "Notendur",
    "Groups" : "Hópar",
    "Test Configuration" : "Prúfa uppsetningu",
    "Help" : "Hjálp",
    "Host" : "Netþjónn",
    "Port" : "Gátt",
    "Password" : "Lykilorð",
    "Continue" : "Halda áfram",
    "Advanced" : "Ítarlegt",
    "Server" : "Þjónn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
